# Generated by Django 4.2.20 on 2025-05-22 15:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0237_enterprisecustomersupportusersview'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_learner_credit_message_box',
            field=models.BooleanField(default=True, help_text='Specifies whether to display the Learner Credit message box in the learner portal.', verbose_name='Display learner credit message box in learner portal'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_learner_credit_message_box',
            field=models.BooleanField(default=True, help_text='Specifies whether to display the Learner Credit message box in the learner portal.', verbose_name='Display learner credit message box in learner portal'),
        ),
    ]
