# Generated by Django 4.2.13 on 2024-05-29 07:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('xapi', '0011_alter_xapilearnerdatatransmissionaudit_index_together'),
    ]

    operations = [
        migrations.AddField(
            model_name='xapilearnerdatatransmissionaudit',
            name='is_transmitted',
            field=models.BooleanField(default=False),
        ),
    ]
