# Generated by Django 4.2.20 on 2025-05-05 19:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0236_create_vw_enterprise_customer_ecus_pecus'),
    ]

    operations = [
        migrations.CreateModel(
            name='EnterpriseCustomerSupportUsersView',
            fields=[
                ('enterprise_customer_id', models.UUIDField()),
                ('user_email', models.EmailField(max_length=254, primary_key=True, serialize=False)),
                ('is_pending', models.BooleanField(default=False)),
                ('user_id', models.PositiveIntegerField()),
                ('username', models.CharField(max_length=150)),
                ('first_name', models.CharField(max_length=150)),
                ('last_name', models.CharField(max_length=150)),
                ('is_staff', models.BooleanField(default=False)),
                ('is_active', models.BooleanField(default=False)),
                ('date_joined', models.DateTimeField(null=True)),
                ('is_admin', models.BooleanField(default=False)),
            ],
            options={
                'db_table': 'view_enterprise_customer_support_users',
                'managed': False,
            },
        ),
    ]
