# Generated by Django 4.2.20 on 2025-05-22 15:18

from django.db import migrations


def backfill_enable_learner_credit_message_box(apps, schema_editor):
    """
    Backfill enable_learner_credit_message_box field for all existing EnterpriseCustomer records.
    """
    EnterpriseCustomer = apps.get_model('enterprise', 'EnterpriseCustomer')
    EnterpriseCustomer.objects.all().update(enable_learner_credit_message_box=True)

class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0238_enterprisecustomer_enable_learner_credit_message_box_and_more'),
    ]

    operations = [
        migrations.RunPython(
            backfill_enable_learner_credit_message_box,
            reverse_code=migrations.RunPython.noop
        ),
    ]
