# Generated by Django 2.2.19 on 2021-03-01 13:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0123_enterprisecustomeridentityprovider_default_provider'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomer',
            name='sender_alias',
            field=models.CharField(blank=True, help_text='Specifies enterprise customized sender alias.', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='sender_alias',
            field=models.CharField(blank=True, help_text='Specifies enterprise customized sender alias.', max_length=255, null=True),
        ),
    ]
