# Generated by Django 3.2.22 on 2024-02-06 11:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('canvas', '0032_alter_historicalcanvasenterprisecustomerconfiguration_options'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='canvaslearnerdatatransmissionaudit',
            constraint=models.UniqueConstraint(fields=('enterprise_course_enrollment_id', 'course_id'), name='canvas_unique_enrollment_course_id'),
        ),
    ]
