# Generated by Django 2.2.17 on 2020-12-01 18:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('canvas', '0005_auto_20200909_1534'),
    ]

    operations = [
        migrations.CreateModel(
            name='CanvasLearnerAssessmentDataTransmissionAudit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('canvas_user_email', models.CharField(max_length=255)),
                ('enterprise_course_enrollment_id', models.PositiveIntegerField(db_index=True)),
                ('course_id', models.CharField(help_text="The course run's key which is used to uniquely identify the course for Canvas.", max_length=255)),
                ('subsection_id', models.CharField(db_index=True, help_text="The course's subsections's key.", max_length=255)),
                ('grade_point_score', models.FloatField(help_text='The amount of points that the learner scored on the subsection.')),
                ('grade_points_possible', models.FloatField(help_text='The total amount of points that the learner could score on the subsection.')),
                ('grade', models.FloatField(help_text='The grade an enterprise learner received on the reported subsection.')),
                ('subsection_name', models.CharField(help_text="The name given to the subsection being reported. Used for displaying on external LMS'.", max_length=255)),
                ('status', models.CharField(max_length=100)),
                ('error_message', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
    ]
