# Generated by Django 3.2.20 on 2023-09-06 14:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0182_auto_20230829_1741'),
    ]

    operations = [
        migrations.AlterField(
            model_name='enterprisecustomer',
            name='enable_learner_portal_offers',
            field=models.BooleanField(default=False, help_text='Specifies whether enterprise offers will be made known to learners in the learner portal. This only applies to customers with “offers”, the old version of learner credit.', verbose_name='Enable learner credit in the learner portal'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='enable_learner_portal_offers',
            field=models.BooleanField(default=False, help_text='Specifies whether enterprise offers will be made known to learners in the learner portal. This only applies to customers with “offers”, the old version of learner credit.', verbose_name='Enable learner credit in the learner portal'),
        ),
    ]
