# Generated by Django 1.11.23 on 2019-10-01 07:42


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('degreed', '0007_auto_20190925_0730'),
    ]

    operations = [
        migrations.AddField(
            model_name='degreedenterprisecustomerconfiguration',
            name='catalogs_to_transmit',
            field=models.TextField(blank=True, help_text='A comma-separated list of catalog UUIDs to transmit.', null=True),
        ),
        migrations.AddField(
            model_name='historicaldegreedenterprisecustomerconfiguration',
            name='catalogs_to_transmit',
            field=models.TextField(blank=True, help_text='A comma-separated list of catalog UUIDs to transmit.', null=True),
        ),
    ]
