# Generated by Django 3.2.12 on 2022-06-14 16:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0158_remove_is_active_from_role_assignment'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomer',
            name='enable_learner_portal_offers',
            field=models.BooleanField(default=False, help_text='Specifies whether enterprise offers will be made known to learners in the learner portal.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomer',
            name='enable_learner_portal_offers',
            field=models.BooleanField(default=False, help_text='Specifies whether enterprise offers will be made known to learners in the learner portal.'),
        ),
    ]
